@@ -3,20 +3,33 @@ REST Wrapper for signal-cli running on system dbus
 """
 
 
+import os
 from sanic import Sanic
 
 from signal_cli_dbus_rest_api.api import entrypoint
+from signal_cli_dbus_rest_api.version import __version__
 
+dirname = os.path.dirname(os.path.realpath(__file__))
 app = Sanic("signal-cli-dbus-rest-api", env_prefix="SIGNAL_CLI_DBUS_REST_API_")
+app.static(
+    "/openapi/assets/swagger",
+    f"{dirname}/openapi/assets/swagger",
+    name="swagger-assets",
+)
 app.config.FALLBACK_ERROR_FORMAT = "json"
+app.config.OAS_UI_DEFAULT = "swagger"
+app.config.OAS_UI_REDOC = False
+app.config.OAS_PATH_TO_SWAGGER_HTML = f"{dirname}/openapi/assets/swagger/swagger.html"
 app.config.API_HOST = (
     f'{app.config.get("API_HOST", "127.0.0.1")}:{app.config.get("API_PORT", 8080)}'
 )
 app.config.API_BASEPATH = app.config.get("API_BASEPATH")
 app.config.API_SCHEMES = app.config.get("API_SCHEMES", "http,https").split(",")
 app.config.API_LICENSE_NAME = "MIT"
+app.config.API_LICENSE_URL = "https://mit-license.org/"
 app.config.API_TITLE = "Signal Cli REST API"
 app.config.API_DESCRIPTION = "This is the Signal Cli REST API documentation."
+app.config.API_VERSION = __version__
 app.blueprint(entrypoint)
 
 
