@@ -2,11 +2,14 @@
 DBus connection for signal-cli
 """
 
+from re import sub
+
 from pydbus import SystemBus as pydbusSystemBus
+
 from dbus import SystemBus as dbusSystemBus
 
 
-class SignalCLIDBus():  # pylint: disable=too-few-public-methods
+class SignalCLIDBus:  # pylint: disable=too-few-public-methods
     """
     DBus connection for signal-cli
     """
@@ -24,6 +27,9 @@ class SignalCLIDBus():  # pylint: disable=too-few-public-methods
                 str(kwargs.get("number")).encode().decode("unicode_escape").strip("+")
             )
             objectpath = f"/org/asamk/Signal/_{number_escape}"
+        if objectpath and kwargs.get("groupid"):
+            groupid = sub(r"[+|=|/]", "_", kwargs.get("groupid"))
+            objectpath += f"/Groups/{groupid}"
         if kwargs.get("account"):
             objectpath = kwargs.get("account")
         if objectpath:
@@ -37,4 +43,6 @@ class SignalCLIDBus():  # pylint: disable=too-few-public-methods
             )
         else:
             self.pydbusconn = self.pydbus.get("org.asamk.Signal")
-            self.dbusconn = self.dbus.get_object("org.asamk.Signal", "/org/asamk/Signal")
+            self.dbusconn = self.dbus.get_object(
+                "org.asamk.Signal", "/org/asamk/Signal"
+            )
